@@ -253,10 +253,9 @@ class FieldBuilder(foundation.Visitor):
 		key = tree.key or self.name
 		if isinstance(key, AST.Name):
 			reader = static.SimpleReader(key.text)
-		elif isinstance(key, AST.Constant):
-			assert key.kind == 'SIGIL', key.kind
-			assert isinstance(key.value, str)
-			reader = static.ComputedReader(key.value)
+		elif isinstance(key, AST.Sigil):
+			assert key.kind == 'COMPUTED', key.kind
+			reader = static.ComputedReader(key.name.text)
 		else:
 			assert False, type(key)
 		within = self.visit(tree.within)
@@ -266,11 +265,7 @@ class FieldBuilder(foundation.Visitor):
 		# Expanding on this first because it's called first.
 		# The margin notes are the easy bit:
 		margin = self.interpret_margin_notes(frame.margin)
-		
-		# Recursion on the children should be a useful trick...
-		children = SymbolTable()
-		for symbol, definition in frame.fields:
-			children.let(symbol, self.subordinate(symbol).visit(definition))
+		children = self.__children(frame.fields)
 		
 		# There are three possible key types: name, sigil, and None.
 		key = frame.key or self.name
@@ -279,23 +274,43 @@ class FieldBuilder(foundation.Visitor):
 			if '_' in children: reader = static.DefaultReader(axis)
 			else: reader = static.SimpleReader(axis)
 			# However, if there's a field called '_', then we want a default-reader instead?
-		elif isinstance(key, AST.Constant):
-			assert key.kind == 'SIGIL', key.kind
-			assert isinstance(key.value, str)
+		elif isinstance(key, AST.Sigil):
+			assert key.kind == 'COMPUTED', key.kind
 			try: symbol = children.get_declaration('_')
 			except KeyError: pass
 			else:
-				self.mb.source.complain(*key.span, message="This tells me the environment will supply a field name...")
+				self.mb.source.complain(*key.name.span, message="This tells me the environment will supply a field name...")
 				self.mb.source.complain(*symbol.span, message="Therefore, a 'default' field makes no sense.")
 				raise SemanticError()
-			reader = static.ComputedReader(key.value)
+			reader = static.ComputedReader(key.name.text)
 		else:
 			assert False, type(key)
 		
 		return static.FrameDefinition(reader, children.as_dict(), margin)
 	
+	def __children(self, fields:list) -> SymbolTable:
+		# Recursion on the children should be a useful trick...
+		children = SymbolTable()
+		for symbol, definition in fields:
+			children.let(symbol, self.subordinate(symbol).visit(definition))
+		return children
+	
 	def visit_Menu(self, menu:AST.Menu) -> static.MenuDefinition:
-		# FIXME: The implementation will be very similar to visit_Frame.
-		print("FIXME:", menu)
-		pass
+		# Expanding on this first because it's called first.
+		# The margin notes are the easy bit:
+		margin = self.interpret_margin_notes(menu.margin)
+		children = self.__children(menu.fields)
+		assert '_' not in children, "This is grammatically impossible!"
+		
+		# There are three possible key types: name, sigil, and None.
+		key = menu.key or self.name
+		if isinstance(key, AST.Name):
+			reader = static.SimpleReader(key.text)
+		elif isinstance(key, AST.Sigil):
+			assert key.kind == 'COMPUTED', key.kind
+			reader = static.ComputedReader(key.name.text)
+		else:
+			assert False, type(key)
+		
+		return static.MenuDefinition(reader, children.as_dict(), margin)
 
